#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Iterates over a bunch of .jpg or .cr2 files and matches 
DateTimeOriginal from Exif tag to DateTime in a csv log 
of a GeigerMuellerCounter."""

from datetime import datetime
from PIL import Image
import piexif
import piexif.helper

# Constants for GQ geiger counters

# 300  series: 0.0065   µSv/h / CPM
# 320  series: 0.0065   µSv/h / CPM
# 500  series: 0.0065   µSv/h / CPM
# 500+ series: 0.0065   µSv/h / CPM for the first tube
# 600  series: 0.0065   µSv/h / CPM
# 600+ series: 0.002637 µSv/h / CPM

SIFACTOR = 0.0065 

# Temp constants
RAD = "0,15"

# Load Image and EXIF data
im = Image.open("testdata/DSC_0183.JPG")
exif_dict = piexif.load(im.info["exif"])

picrawtime = exif_dict["Exif"][piexif.ExifIFD.DateTimeOriginal].decode('ASCII')
picisotime = datetime.strptime(picrawtime, "%Y:%m:%d %H:%M:%S")

print("Timestamp of image: ", picisotime)

# Import GeigerCounter log
with open("testdata/test.hisdb.his", "r") as f:
    for line in f:
        if line[0] != '#':
            columns = line.split(',')
            csvrawtime = columns[1].lstrip()
            csvrawcpm = columns[2].lstrip()
            csvisotime = datetime.fromisoformat(csvrawtime)
            
            if csvisotime == picisotime:
                rad = round(float(csvrawcpm) * SIFACTOR, 2)
                print("Radiation at time of photo: ", rad, "µS/h")

                # convert str to exif compatible string
                new_comment = "Radiation ☢ " + str(rad) + " µS/h"
                user_comment = piexif.helper.UserComment.dump(new_comment, encoding="unicode")
                exif_dict["Exif"][piexif.ExifIFD.UserComment] = user_comment
                
                # compile and write tags
                print("Going to write comment: " + new_comment)
                exif_bytes = piexif.dump(exif_dict)
                im.save("testdata/test.jpg", exif=exif_bytes)
                break
